package cz.novoj.business;
/**
 * Description
 * @author Jan Novotn, FG Forrest a.s. (c) 2007
 * @version $Id: $
 */

import cz.novoj.log.SpringTransactionTestAppender;
import cz.novoj.log.CustomSecurityTestAppender;
import cz.novoj.business.interceptor.NaiveSecurityInterceptor;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.junit.After;
import org.junit.Before;
import static org.junit.Assert.assertTrue;
import static org.junit.Assert.assertFalse;
import org.springframework.beans.factory.annotation.Autowired;

public class UserManagerIntegrationTest extends UserManagerTest {
	private static Log log = LogFactory.getLog(UserManagerTest.class);
	@Autowired(required = true)
	UserManager userManager;
	@Autowired(required = true)
	NaiveSecurityInterceptor securityInterceptor;
	SpringTransactionTestAppender transactionTestAppender;
	CustomSecurityTestAppender securityTestAppender;

	@Before
	public void initLogger() {
		transactionTestAppender = new SpringTransactionTestAppender();
		securityTestAppender = new CustomSecurityTestAppender();
	}

	@After
	public void closeLogger() {
		transactionTestAppender.close();
		securityTestAppender.close();
	}

	public void testCreateUserWithPropertiesTransaction() throws Exception {
		try {
			super.testCreateUserWithProperties();
		} catch (Exception ex) {
			String msg = "Logging error: " + ex.getMessage();
			log.error(msg, ex);
		} finally {
			String methodName = "createUserWithProperties";
			assertTrue(transactionTestAppender.isTransactionOpened(UserManager.class, methodName));
			assertTrue(transactionTestAppender.isTransactionCommited(UserManager.class, methodName));
			assertFalse(transactionTestAppender.isTransactionRollbacked(UserManager.class, methodName));
		}
	}

	public void testCreateUserWithPropertiesSecurityAllowed() throws Exception {
		try {
			super.testCreateUserWithProperties();
		} catch (Exception ex) {
			String msg = "Logging error: " + ex.getMessage();
			log.error(msg, ex);
		} finally {
			String methodName = "createUserWithProperties";
			assertTrue(securityTestAppender.isAllowed(UserManager.class, methodName));
		}
	}

	public void testCreateUserWithPropertiesSecurityDenied() throws Exception {
		try {
			securityInterceptor.setBlock(true);
			super.testCreateUserWithProperties();
		} catch (Exception ex) {
			String msg = "Logging error: " + ex.getMessage();
			log.error(msg, ex);
		} finally {
			String methodName = "createUserWithProperties";
			assertTrue(securityTestAppender.isBlocked(UserManager.class, methodName));
		}
	}

}